# error.pl: error handler
# $Id: error.pl,v 1.1.1.1 2000/03/18 06:54:10 odakker Exp $
# Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
# see COPYING.TXT for terms of license.

sub die {
	local($msg) = @_;
	print STDERR "ERROR: $msg\n";
	exit 2;
}

sub warn {
	local($msg) = @_;
	print STDERR "WARNING: $msg\n";
	$exit = 1;
}

sub okay {
	local($msg) = join(' ', @_);
	print STDERR "OK: $msg\n";
}

sub exit {
	exit $exit;
}
